@@ -1,7 +1,7 @@
 package Simulation::DiscreteEvent::Server;
 
 use Moose;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use Moose::Util::MetaRole;
 BEGIN {
     extends 'MooseX::MethodAttributes::Inheritable';
@@ -16,7 +16,9 @@ Simulation::DiscreteEvent::Server - Moose class for implementing servers
 
     package MyServer;
     use Moose;
-    use parent 'Simulation::DiscreteEvent::Server';
+    BEGIN {
+        extends 'Simulation::DiscreteEvent::Server';
+    }
     sub handler1 : Event(start) {
         # handle start event here
     }
